# agi-med-utils

Стандартизация компонент общей библиотеки отдела

## Ответственный разработчик

@bakulin

## Общая информация

### Фичи: 

- Доступ к Yandex_GPT, Gigachat
- Стандартный конфиг

## Тесты

- `sudo docker-compose -f docker-compose.yaml up --build`

